darkhistory.electrons.ics.BE_integrals.F_inv_n — DarkHistory documentation

# darkhistory.electrons.ics.BE_integrals.F_inv_n

`darkhistory.electrons.ics.BE_integrals.` `F_inv_n`(a, b, n, tol=1e-10)

  Definite integral of (1/x**n)/(exp(x) - 1)

  Parameters: | a : ndarray Lower limit of integration. b : ndarray Upper limit of integration. tol : float The relative tolerance to be reached.
  Returns: | float The resulting integral.

#### Previous topic

darkhistory.electrons.ics.BE_integrals.F_inv_a

#### Next topic

darkhistory.electrons.ics.BE_integrals.F_log

### This Page

Show Source